# This file was auto-generated by Fern from our API Definition.

import typing

from .templates_create_template_request_agent_file import TemplatesCreateTemplateRequestAgentFile
from .templates_create_template_request_agent_id import TemplatesCreateTemplateRequestAgentId

TemplatesCreateTemplateRequest = typing.Union[
    TemplatesCreateTemplateRequestAgentId, TemplatesCreateTemplateRequestAgentFile
]
