# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.approval_create import ApprovalCreate
from ....types.message_create import MessageCreate

LettaAsyncRequestMessagesItem = typing.Union[MessageCreate, ApprovalCreate]
