# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .passages_search_request_tag_match_mode import PassagesSearchRequestTagMatchMode

__all__ = ["PassagesSearchRequestTagMatchMode"]
