# This file was auto-generated by Fern from our API Definition.

import typing

from .agents_create_response_group_min_message_buffer_length_item import (
    AgentsCreateResponseGroupMinMessageBufferLengthItem,
)

AgentsCreateResponseGroupMinMessageBufferLength = typing.Union[
    float,
    typing.Optional[str],
    typing.List[typing.Optional[AgentsCreateResponseGroupMinMessageBufferLengthItem]],
    typing.Optional[typing.Any],
]
