# This file was auto-generated by Fern from our API Definition.

import typing

from .agents_create_response_group_hidden_item import AgentsCreateResponseGroupHiddenItem

AgentsCreateResponseGroupHidden = typing.Union[
    bool,
    typing.Optional[str],
    typing.List[typing.Optional[AgentsCreateResponseGroupHiddenItem]],
    typing.Optional[typing.Any],
]
