# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.unchecked_base_model import UncheckedBaseModel
from .agents_create_response_group_base_template_id import AgentsCreateResponseGroupBaseTemplateId
from .agents_create_response_group_deployment_id import AgentsCreateResponseGroupDeploymentId
from .agents_create_response_group_hidden import AgentsCreateResponseGroupHidden
from .agents_create_response_group_last_processed_message_id import AgentsCreateResponseGroupLastProcessedMessageId
from .agents_create_response_group_manager_agent_id import AgentsCreateResponseGroupManagerAgentId
from .agents_create_response_group_manager_type import AgentsCreateResponseGroupManagerType
from .agents_create_response_group_max_message_buffer_length import AgentsCreateResponseGroupMaxMessageBufferLength
from .agents_create_response_group_max_turns import AgentsCreateResponseGroupMaxTurns
from .agents_create_response_group_min_message_buffer_length import AgentsCreateResponseGroupMinMessageBufferLength
from .agents_create_response_group_project_id import AgentsCreateResponseGroupProjectId
from .agents_create_response_group_shared_block_ids import AgentsCreateResponseGroupSharedBlockIds
from .agents_create_response_group_sleeptime_agent_frequency import AgentsCreateResponseGroupSleeptimeAgentFrequency
from .agents_create_response_group_template_id import AgentsCreateResponseGroupTemplateId
from .agents_create_response_group_termination_token import AgentsCreateResponseGroupTerminationToken
from .agents_create_response_group_turns_counter import AgentsCreateResponseGroupTurnsCounter


class AgentsCreateResponseGroup(UncheckedBaseModel):
    id: str
    manager_type: AgentsCreateResponseGroupManagerType
    agent_ids: typing.List[str]
    description: str
    project_id: typing.Optional[AgentsCreateResponseGroupProjectId] = None
    template_id: typing.Optional[AgentsCreateResponseGroupTemplateId] = None
    base_template_id: typing.Optional[AgentsCreateResponseGroupBaseTemplateId] = None
    deployment_id: typing.Optional[AgentsCreateResponseGroupDeploymentId] = None
    shared_block_ids: typing.Optional[AgentsCreateResponseGroupSharedBlockIds] = None
    manager_agent_id: typing.Optional[AgentsCreateResponseGroupManagerAgentId] = None
    termination_token: typing.Optional[AgentsCreateResponseGroupTerminationToken] = None
    max_turns: typing.Optional[AgentsCreateResponseGroupMaxTurns] = None
    sleeptime_agent_frequency: typing.Optional[AgentsCreateResponseGroupSleeptimeAgentFrequency] = None
    turns_counter: typing.Optional[AgentsCreateResponseGroupTurnsCounter] = None
    last_processed_message_id: typing.Optional[AgentsCreateResponseGroupLastProcessedMessageId] = None
    max_message_buffer_length: typing.Optional[AgentsCreateResponseGroupMaxMessageBufferLength] = None
    min_message_buffer_length: typing.Optional[AgentsCreateResponseGroupMinMessageBufferLength] = None
    hidden: typing.Optional[AgentsCreateResponseGroupHidden] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
